@@ -25,8 +25,8 @@ args = parser.parse_args()
 
 GifAscii(
     file_name=args.f,
-    width=args.w,
-    frame_delay=args.d,
+    width=int(args.w),
+    frame_delay=float(args.d),
     chars=args.c,
     fit_terminal=args.fit_terminal,
     loop_gif=not args.no_loop
